@@ -16,12 +16,12 @@ Net::WebSocket::Frame::binary
         #Optional, can be either empty (default) or four random bytes
         mask => q<>,
 
-        payload_sr => \$payload_text,
+        payload => $payload_octet_string,
     );
 
     $frm->get_type();           #"binary"
 
-    $frm->is_control_frame();   #0
+    $frm->is_control();   #0
 
     my $mask = $frm->get_mask_bytes();
 
@@ -33,6 +33,9 @@ Net::WebSocket::Frame::binary
 
 =cut
 
+use strict;
+use warnings;
+
 use parent qw(
     Net::WebSocket::Base::DataFrame
 );
